<template>
  <div class="GaugeMonitorEcharts">
    <div class="gaugeBg">
      <div class="gaugeImg imgBox">
        <img src="../../../assets/img/warnAnalysis/leftCharts/gaugeBg.png" alt="">
      </div>
    </div>
    <div class="ClassItem">
      <div class="ClassStatistics">
        <div class="ClassProportion">
          <echarts class="GaugeMonitorEchartsContainer" :chart-id="'GaugeMonitorEcharts' + id" :chart-option="options" v-if="isShow"></echarts>
          <!-- <el-empty :image="imgSrc" :image-size="80" description="暂无数据" v-else></el-empty> -->
        </div>
      </div>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
export default {
  name: 'GaugeMonitorEcharts',
  props: {
    dataObj: {
      type: Object,
      default: () => {
        return {}
      }
    },
    id:  {
      type: Number,
      default: () => {
        return 0
      }
    }
  },
  data() {
    return {
      isShow: true,
      options: {}
    }
  },
  created() {
  },
  mounted() {
    this.$nextTick(() => {
      this.initChart(this.dataObj)
    })
  },
  watch: {
    dataObj(nV) {
      // console.log(nV)
      this.initChart(nV)
    }
  },
  methods: {
    initChart(data) {
      this.options = {
        tooltip: {
          formatter: data.name + "<br/>值 : {c}"
        },
        title: [
          { //标题
            text: '0',
            bottom:'20%',
            left: '12%',
            textStyle:{
              fontSize: '12',
              fontFamily: 'Alimama ShuHeiTi',
              fontWeight: 'bold',
              color: '#FFFFFF',
            }
          },
          {
            text: '100',
            bottom:'20%',
            right: '5%',
            textStyle: {
              fontSize: '12',
              fontFamily: 'Alimama ShuHeiTi',
              fontWeight: 'bold',
              color: '#FFFFFF',
            }
          },
          {
            text: data.value,
            bottom:'26%',
            left: '42.5%',
            textStyle: {
              fontFamily: 'Alimama ShuHeiTi',
              fontWeight: 'bold',
              color: data.name  == '燃气' ? '#FFB756': data.name == '供水' ? '#F2EC13': data.name  == '桥梁' ? '#F2EC13' : '#56FFA5',
              fontSize: '14'
            }
          }
        ],
        grid: {
          top: 0,
          left: 0,
          right: 0,
          bottom: 0,
        },
        series: [
          // 外一层圈
          {
            type: 'pie',
            radius: '25%',
            silent: false,
            startAngle: 220,
            endAngle: -40,
            hoverAnimation: false,
            center: ['50%', '64%'],
            avoidLabelOverlap: false,
            label: {
              show: false,
            },
            labelLine: {
              show: false,
            },
            data: [
              {
                value: data.value,
              },
            ],
            itemStyle: {
              normal: {
                color: new echarts.graphic.RadialGradient(.5, .5, 1, [{
                    offset: 0,
                    color: 'rgba(17,24,43,0)'
                  },
                  {
                    offset: .5,
                    // color: '#1E2B57'
                    color:'rgba(2,86,110,0.75)'
                  },
                  {
                    offset: 1,
                    color: '#02566E',
                    // color:'rgba(17,24,43,0)'
                  }
                ], false)
              }
            }
          },
          {
            name: data.name,
            type: "gauge",
            center: ['50%', '65%'],
            radius: '66%',
            hoverAnimation: false,
            legendHoverLink: false,
            silent: true,
            min: 0, //最小刻度
            max: 100, //最大刻度
            splitNumber: 1, //刻度数量
            startAngle: 180,
            endAngle: 0,
            // 这是指针的颜色
            color: 'rgba(255,255,255,1)',
            axisLine: {
              lineStyle: {
                color: [
                  [data.value / 100, new echarts.graphic.LinearGradient(
                    0, 0, 1, 0, [{
                        offset: 0,
                        // color: 'rgba(223,255,238,1)'
                        color: data.name  == '燃气' ? '#FFF0DB': data.name == '供水' ? '#FFF0DB': data.name  == '桥梁' ? '#FFF0DB' : 'rgba(223,255,238,1)'
                      },
                      {
                        offset: 1,
                        // color: 'rgba(60,223,136,1)'
                        color: data.name  == '燃气' ? '#F7B65B': data.name == '供水' ? '#F2EC13': data.name  == '桥梁' ? '#F2EC13' : 'rgba(60,223,136,1)'
                      }
                    ]
                  )],
                  [1, '#CCDAE5']
                ],
                width: 15
              }
            },
            axisLabel: {
              show: false,
              fontSize: '12',
              fontFamily: 'Alimama ShuHeiTi',
              fontWeight: 'bold',
              color: '#FFFFFF',
              formatter: "{value}",
              distance: -25,
              padding: [20, 0, 0, 8],
            },
            axisTick: {
              show: false,
            },
            splitLine: {
              show: false,
            },
            itemStyle: {
              show: false,
            },
            detail: {
              textStyle: {
                fontSize: '12',
                fontFamily: 'Alimama ShuHeiTi',
                fontWeight: 'bold',
                color: '#FFFFFF'
              },
              show: true,
              offsetCenter: [0, '60%'],
              formatter: (value) => {
                return [
                  data.name
                ]
              },
            },
            data: [{
              value: data.value,
            }],
            pointer: {
              show: true,
              icon: 'triangle',
              length: '175%',
              radius: '50%',
              width: 3, //指针粗细
              offsetCenter: [0, 25, 0, 0]
            },
            animationDuration: 4000
          },
          {
            //指针上的圆
            type: 'pie',
            tooltip: {
              show: false,
            },
            z: 5,
            silent: false,
            hoverAnimation: false,
            legendHoverLink: false,
            radius: ['0%', '13%'],
            center: ['50%', '65%'],
            label: {
                normal: {
                  show: false,
                },
            },
            labelLine: {
                normal: {
                  show: false,
                },
            },
            itemStyle: {
              normal: {
                color: '#333333'
              }
            },
            data: [
                {
                  value: 10
                }
            ],
          },
        ]
      }
    }
  }
}

</script>

<style lang="scss" scoped>
.GaugeMonitorEcharts{
  position: absolute;
  top: 0;
  width: 100%;
  height: 100%;
  .gaugeBg{
    width: 147px;
    height: 77px;
    position: absolute;
    top:15.5%;
    left: 11.5%;
  }
  .ClassItem{
    position: relative;
    height: 100%;
    box-sizing: border-box;
    .ClassStatistics {
      display: flex;
      align-items: center;
      height: 100%;
      .ClassProportion {
        overflow: hidden;
        width: 100%;
        height: 100%;
        .GaugeMonitorEchartsContainer{
          width: 100%;
          height: 100%;
        }
      }
    }
  }
}
</style>
